@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kva_query.cpp,v 1.23.2.1 2002/04/12 10:09:28 coolo Exp $
+    $Id: kva_query.cpp,v 1.24 2002/04/12 10:09:55 coolo Exp $
 
                        query parts of kvoctrain
 
@@ -15,7 +15,7 @@
     -----------------------------------------------------------------------
 
     $Log: kva_query.cpp,v $
-    Revision 1.23.2.1  2002/04/12 10:09:28  coolo
+    Revision 1.24  2002/04/12 10:09:55  coolo
     replacing tons of these (for gcc 3):
     -      queryList.erase(&queryList[i], &queryList[i+1]);
     +      queryList.erase(queryList.begin() + i);
