@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvoctrain.cpp,v 1.44.2.1 2002/04/12 10:09:28 coolo Exp $
+    $Id: kvoctrain.cpp,v 1.54 2002/11/14 22:52:35 mueller Exp $
 
                       main part of kvoctrain
 
@@ -16,7 +16,34 @@
     -----------------------------------------------------------------------
 
     $Log: kvoctrain.cpp,v $
-    Revision 1.44.2.1  2002/04/12 10:09:28  coolo
+    Revision 1.54  2002/11/14 22:52:35  mueller
+    compiler warning fixes
+
+    Revision 1.53  2002/10/23 18:16:48  asserhal
+    Changed tr to i18n
+
+    Revision 1.52  2002/09/17 20:24:59  binner
+    CVS_SILENT Style guide fix, use "cvslastchange" or X-WebCVS header line to view
+
+    Revision 1.51  2002/07/23 12:39:19  binner
+    CVS_SILENT Style guide fixes
+
+    Revision 1.50  2002/07/21 05:12:04  binner
+    Use KLineEditDlg and QInputDialog.
+
+    Revision 1.49  2002/07/21 04:27:08  binner
+    CVS_SILENT Style guide fixes
+
+    Revision 1.48  2002/05/09 09:48:55  arnold
+    fixed i18n issue
+
+    Revision 1.47  2002/05/09 09:18:27  arnold
+    fixed missing entry dialog
+
+    Revision 1.46  2002/04/20 12:55:48  binner
+    CVS_SILENT Capitalisation fixes.
+
+    Revision 1.45  2002/04/12 10:09:55  coolo
     replacing tons of these (for gcc 3):
     -      queryList.erase(&queryList[i], &queryList[i+1]);
     +      queryList.erase(queryList.begin() + i);
@@ -193,6 +220,7 @@
 #include <kdebug.h>
 
 #include <qcursor.h>
+#include <qinputdialog.h>
 #include <qtimer.h>
 #include <qfile.h>
 #include <qtooltip.h>
@@ -200,7 +228,6 @@
 
 #include <time.h>
 #include <ctype.h>
-#include <iostream.h>
 
 #include <kvoctraincore.h>
 #include "kvoctraindoc.h"
@@ -212,7 +239,6 @@
 #include "docprop-dialogs/DocPropLangDlg.h"
 #include "common-dialogs/ProgressDlg.h"
 #include "statistik-dialogs/StatistikDlg.h"
-#include "common-dialogs/NumLessonDlg.h"
 
 
 void kvoctrainApp::slotSaveOptions()
@@ -588,6 +614,11 @@ void kvoctrainApp::createEntryDlg(int row, int col)
    opts_menu->setItemEnabled(ID_VIEW_INLINE, false);
    view->getTable()->setEditorBlocked(true);
 
+   if (col == 0)
+     entryDlg->setEnabled(EntryDlg::EnableOnlyOriginal);
+   else
+     entryDlg->setEnabled(EntryDlg::EnableAll);
+
    vector<QTableSelection> tabsel;
    entryDlg->setCell(row, col+KV_EXTRA_COLS, tabsel);
    entryDlg->initFocus();
@@ -784,7 +815,7 @@ void kvoctrainApp::slotDocProps ()
       doc->setLicense(ddlg.getLicense() );
       doc->setDocRemark(ddlg.getDocRemark() );
 
-      slotStatusMsg(i18n("updating lesson indices..."));
+      slotStatusMsg(i18n("Updating lesson indices..."));
       QApplication::setOverrideCursor( waitCursor );
 
       ddlg.getLesson(lessons, lessonIndex);
@@ -797,16 +828,16 @@ void kvoctrainApp::slotDocProps ()
       for (int i = 1; i < lessons->count(); i++)
         new_lessonStr.push_back(lessons->text(i));
 
-      slotStatusMsg(i18n("updating type indices..."));
+      slotStatusMsg(i18n("Updating type indices..."));
       TypeOptPage::cleanUnused(doc, typeIndex, old_types);
       QueryManager::setTypeNames (new_typeStr);
 
-      slotStatusMsg(i18n("updating tense indices..."));
+      slotStatusMsg(i18n("Updating tense indices..."));
       TenseOptPage::cleanUnused(doc, tenseIndex, old_tenses);
       Conjugation::setTenseNames (new_tenseStr);
 
       slotStatusMsg(i18n("usage (area) of an expression",
-                         "updating usage label indices..."));
+                         "Updating usage label indices..."));
       UsageOptPage::cleanUnused(doc, usageIndex, old_usages);
       UsageManager::setUsageNames (new_usageStr);
 
@@ -872,7 +903,7 @@ void kvoctrainApp::slotRemoveRow()
 
   if (!hasSelection()) {
     if( KMessageBox::Yes == KMessageBox::questionYesNo(this,
-                  i18n("Do you really want to delete the selected entry ?\n"),
+                  i18n("Do you really want to delete the selected entry?\n"),
                   kapp->makeStdCaption("")))
     {
       RowTable *table = view->getTable();
@@ -883,7 +914,7 @@ void kvoctrainApp::slotRemoveRow()
   }
   else {
     if(KMessageBox::Yes == KMessageBox::questionYesNo(this,
-                  i18n("Do you really want to delete the selected range ?\n"),
+                  i18n("Do you really want to delete the selected range?\n"),
                   kapp->makeStdCaption("")));
     {
       RowTable *table = view->getTable();
@@ -1069,11 +1100,14 @@ void kvoctrainApp::slotCleanVocabulary ()
 
 void kvoctrainApp::slotCreateRandom()
 {
-   NumLessonDlg numDlg (entriesPerLesson, this, "name");
-   if (numDlg.exec() != QDialog::Accepted)
+   bool ok = FALSE;
+   int res = QInputDialog::getInteger(
+                i18n( "Entries in Lesson" ),
+                i18n( "Enter number of entries in lesson:" ), 1, 1, 1000, 1, &ok, this );
+   if (!ok)
      return;
 
-   entriesPerLesson = numDlg.getInput();
+   entriesPerLesson = res;
 
    slotStatusMsg(i18n("Creating random lessons..."));
    QApplication::setOverrideCursor( waitCursor );
@@ -1203,7 +1237,7 @@ void kvoctrainApp::slotAppendLang(int header_and_cmd)
      QString msg = i18n("To append a new language which is not listed in "
                         "the submenu, you must first add its data in the "
                         "general options dialog.\n"
-                        "Should this dialog be invoked now ?");
+                        "Should this dialog be invoked now?");
     if( KMessageBox::Yes == KMessageBox::questionYesNo(this,
                   msg,
                   kapp->makeStdCaption("")));
@@ -1381,11 +1415,11 @@ void kvoctrainApp::aboutToShowLearn()
         if((j = langset.indexShortId(doc->getIdent(i))) >= 0
            && !langset.PixMapFile(j).isEmpty()
            && !langset.longId(j).isEmpty() ) {
-          query_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("from ")+main_names[i],
+          query_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("from %1").arg(main_names[i]),
               (i << (16+8)) |  IDH_START_QUERY);  // hack: IDs => header-ids + cmd
         }
         else {
-          query_m->insertItem(i18n("from ")+doc->getIdent(i), (i << (16+8)) |  IDH_START_QUERY);
+          query_m->insertItem(i18n("from %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_QUERY);
         }
       }
 
@@ -1399,11 +1433,11 @@ void kvoctrainApp::aboutToShowLearn()
         if((j = langset.indexShortId(doc->getIdent(i))) >= 0
            && !langset.PixMapFile(j).isEmpty()
            && !langset.longId(j).isEmpty() ) {
-          multiple_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("from ")+main_names[i],
+          multiple_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("from %1").arg(main_names[i]),
               (i << (16+8)) |  IDH_START_MULTIPLE);  // hack: IDs => header-ids + cmd
         }
         else {
-          multiple_m->insertItem(i18n("from ")+doc->getIdent(i), (i << (16+8)) |  IDH_START_MULTIPLE);
+          multiple_m->insertItem(i18n("from %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_MULTIPLE);
         }
       }
       header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-multi.xpm")), i18n("Create &Multiple Choice"), multiple_m, (4 << 16) | IDH_NULL);
@@ -1482,7 +1516,7 @@ void kvoctrainApp::aboutToShowVocabulary() {
         add_m->insertItem(names[i],
           (i << 16) | IDH_APPEND);
     }
-    add_m->insertItem(i18n("Another Language"), (0xFF << 16) | IDH_APPEND);
+    add_m->insertItem(i18n("Another Language..."), (0xFF << 16) | IDH_APPEND);
 
     connect (add_m, SIGNAL(activated(int)), this, SLOT(slotAppendLang(int)));
     connect (add_m, SIGNAL(highlighted(int)), this, SLOT(slotHeaderStatus(int)));
@@ -1633,9 +1667,9 @@ void kvoctrainApp::statusCallback(int id_){
     ON_STATUS_MSG(ID_SEL_ALL,           i18n("Selects all entries"))
     ON_STATUS_MSG(ID_CLR_SEL,           i18n("Deselects all entries"))
 
-    ON_STATUS_MSG(ID_VIEW_TOOLBAR,      i18n("Enables / disables the current toolbar"))
-    ON_STATUS_MSG(ID_VIEW_STATUSBAR,    i18n("Enables / disables the statusbar"))
-    ON_STATUS_MSG(ID_VIEW_INLINE,       i18n("Enables / disables inline editing in the table view"))
+    ON_STATUS_MSG(ID_VIEW_TOOLBAR,      i18n("Enables/disables the current toolbar"))
+    ON_STATUS_MSG(ID_VIEW_STATUSBAR,    i18n("Enables/disables the statusbar"))
+    ON_STATUS_MSG(ID_VIEW_INLINE,       i18n("Enables/disables inline editing in the table view"))
     ON_STATUS_MSG(ID_SAVE_OPTIONS,      i18n("Saves options"))
     ON_STATUS_MSG(ID_DOC_PROPS,         i18n("Edits document properties"))
     ON_STATUS_MSG(ID_DOC_PROPS_LANG,    i18n("Edits language properties in current document"))
