@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: GrammerManager.cpp,v 1.5.2.1 2002/04/12 10:09:28 coolo Exp $
+    $Id: GrammerManager.cpp,v 1.7 2002/07/21 04:27:09 binner Exp $
 
              manage grammer parts (articles, conjugation)
 
@@ -15,7 +15,10 @@
     -----------------------------------------------------------------------
 
     $Log: GrammerManager.cpp,v $
-    Revision 1.5.2.1  2002/04/12 10:09:28  coolo
+    Revision 1.7  2002/07/21 04:27:09  binner
+    CVS_SILENT Style guide fixes
+
+    Revision 1.6  2002/04/12 10:09:56  coolo
     replacing tons of these (for gcc 3):
     -      queryList.erase(&queryList[i], &queryList[i+1]);
     +      queryList.erase(queryList.begin() + i);
@@ -55,13 +58,13 @@
 Conjugation::conjug_name_t
 Conjugation::names [] =
 {
-  { CONJ_SIMPLE_PRESENT,    I18N_NOOP("Simple preset") },
-  { CONJ_PRESENT_PROGR,     I18N_NOOP("Preset progressive") },
-  { CONJ_PRESENT_PERFECT,   I18N_NOOP("Preset perfect") },
+  { CONJ_SIMPLE_PRESENT,    I18N_NOOP("Simple Preset") },
+  { CONJ_PRESENT_PROGR,     I18N_NOOP("Preset Progressive") },
+  { CONJ_PRESENT_PERFECT,   I18N_NOOP("Preset Perfect") },
 
-  { CONJ_SIMPLE_PAST,       I18N_NOOP("Simple past") },
-  { CONJ_PAST_PROGR,        I18N_NOOP("Past progressive") },
-  { CONJ_PAST_PARTICIPLE,   I18N_NOOP("Past participle") },
+  { CONJ_SIMPLE_PAST,       I18N_NOOP("Simple Past") },
+  { CONJ_PAST_PROGR,        I18N_NOOP("Past Progressive") },
+  { CONJ_PAST_PARTICIPLE,   I18N_NOOP("Past Participle") },
 
   { CONJ_FUTURE,            I18N_NOOP("Future") }
 };
