@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvd_wkvtml.cpp,v 1.10 2002/02/08 19:24:03 arnold Exp $
+    $Id: kvd_wkvtml.cpp,v 1.12 2002/09/27 18:08:37 arnold Exp $
 
                          write a kvtml document
 
@@ -15,6 +15,12 @@
     -----------------------------------------------------------------------
 
     $Log: kvd_wkvtml.cpp,v $
+    Revision 1.12  2002/09/27 18:08:37  arnold
+    fixed saving (conjugation got lost)
+
+    Revision 1.11  2002/04/19 09:12:11  arnold
+    xml structure now more conforming
+
     Revision 1.10  2002/02/08 19:24:03  arnold
     fixed sleeping dialog, applied patches for Tru64 unix
 
@@ -625,8 +631,8 @@ bool kvoctrainDoc::saveToKvtMl (QTextStream& os, QString &title) {
   XmlWriter xml (os);
   xml.setAutoEndl (false);
 
-  xml.startTag ("!doctype", false);
-  xml.writeText (" kvtml system \"kvoctrain.dtd\"");
+  xml.startTag ("!DOCTYPE", false);
+  xml.writeText (" kvtml SYSTEM \"kvoctrain.dtd\"");
   xml.closeTag (false, true);
 
   xml.startTag ("!--", false, true, true);
@@ -686,12 +692,10 @@ bool kvoctrainDoc::saveToKvtMl (QTextStream& os, QString &title) {
                  " - Close all tags\n"
                  " - Keep proper hierarchy\n"
                  " - All attributes are quoted\n"
-                 "\n"
-                 "--"
-                 "\n");
-
+                 "--");
   xml.closeTag (false, true);
 
+  xml.writeText ("\n ");
   xml.startTag (KV_DOCTYPE, false);
   xml.writeText ("\n ");
   xml.addAttribute (KV_ENCODING, (QString)"UTF-8");
@@ -846,13 +850,21 @@ bool kvoctrainDoc::saveToKvtMl (QTextStream& os, QString &title) {
     if (!saveMultipleChoice ((*first).getMultipleChoice(0), xml, 1))
         return false;
 
-    if ((*first).getType(0) == QM_VERB
+    QString s;
+    QString entype = s = (*first).getType(0);
+    int pos = s.find (QM_TYPE_DIV);
+    if (pos >= 0)
+      entype = s.left (pos);
+    else
+      entype = s;
+        
+    if (   entype == QM_VERB
         && (*first).getConjugation(0).numEntries() > 0) {
       Conjugation conj = (*first).getConjugation(0);
       if (!saveConjugEntry(conj, xml, 1))
         return false;
     }
-    else if ((*first).getType(0) == QM_ADJ
+    else if (entype == QM_ADJ
         && !(*first).getComparison(0).isEmpty()) {
       Comparison comp = (*first).getComparison(0);
       if (!saveComparison (comp, xml, 1))
@@ -959,14 +971,22 @@ bool kvoctrainDoc::saveToKvtMl (QTextStream& os, QString &title) {
       if (!saveMultipleChoice ((*first).getMultipleChoice(trans), xml, 1))
           return false;
 
-      if (   (*first).getType(trans) == QM_VERB
+      QString s;
+      QString entype = s = (*first).getType(0);
+      int pos = s.find (QM_TYPE_DIV);
+      if (pos >= 0)
+        entype = s.left (pos);
+      else
+        entype = s;
+  
+      if (   entype == QM_VERB
           && (*first).getConjugation(trans).numEntries() > 0) {
         Conjugation conj = (*first).getConjugation(trans);
         if (!saveConjugEntry(conj, xml, 1+trans))
           return false;
       }
 
-      if ((*first).getType(trans) == QM_ADJ
+      if (   entype == QM_ADJ
           && !(*first).getComparison(trans).isEmpty()) {
         Comparison comp = (*first).getComparison(trans);
         if (!saveComparison (comp, xml, 1+trans))
